﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using TXTextControl;

namespace tx_convert_native_to_app
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void btn_browserSource_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == DialogResult.OK)
            {
                cb_source.Text = folderBrowserDialog1.SelectedPath;
            }
        }

        private void btn_browserDestination_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == DialogResult.OK)
            {
                cb_destination.Text = folderBrowserDialog1.SelectedPath;
            }
        }

        private void btn_convert_Click(object sender, EventArgs e)
        {
            tx_convert_native_to_app.Properties.Settings.Default.Save();

            DirectoryInfo sourceDir = new DirectoryInfo(cb_source.Text);

            int i = 1;
            int total = sourceDir.GetFiles().Length;

            foreach (FileInfo template in sourceDir.GetFiles())
            {
                lbl_status.Text = "Processing " + i.ToString() + " of " + total.ToString();
                lbl_status.Refresh();
                i++;

                try
                {
                    StreamType st = StreamType.InternalUnicodeFormat;

                    if (template.Name.EndsWith("docx"))
                        st = StreamType.WordprocessingML;
                    else if (template.Name.EndsWith("doc"))
                        st = StreamType.MSWord;
                    else if (template.Name.EndsWith("rtf"))
                        st = StreamType.RichTextFormat;

                    textControl1.Load(template.FullName, st);

                    foreach (TextField field in textControl1.TextFields)
                    {
                        // store the original general properties
                        bool doubledInput = field.DoubledInputPosition;
                        bool editable = field.Editable;
                        bool deletable = field.Deleteable;

                        field.DoubledInputPosition = true;
                        field.Deleteable = false;
                        field.Editable = true;

                        textControl1.InputPosition = new InputPosition(field.Start + field.Length - 1, TextFieldPosition.OutsideTextField);

                        // create a new ApplicationField and add it
                        ApplicationField newField = new ApplicationField(ApplicationFieldFormat.MSWord, "MERGEFIELD", field.Text, new string[] { field.Name });
                        textControl1.ApplicationFields.Add(newField);

                        // set the original general properties
                        newField.DoubledInputPosition = doubledInput;
                        newField.Deleteable = deletable;
                        newField.Editable = editable;
                    }

                    // remove the TextFields
                    textControl1.TextFields.Clear(false);

                    // add your image handling here
                    foreach (TXTextControl.Image img in textControl1.Images)
                    {
                        img.SaveMode = ImageSaveMode.SaveAsData;
                    }

                    textControl1.Save(cb_destination.Text + "\\" + template.Name, StreamType.RichTextFormat);
                }
                catch (Exception exc)
                {
                    lbl_status.Text = exc.Message;
                    lbl_status.Refresh();
                }
            }
        }

        private void btn_exit_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
